@@ -7,11 +7,11 @@ import os
 from scipy.optimize import curve_fit 
 import copy
 import seaborn as sns
-
+from ssNMR.formatting import format_plot
 from lmfit import Parameters
 from lmfit.models import ExponentialModel, GaussianModel, PseudoVoigtModel
 import pprint
-from formatting import format_plot
+
 
 def simple_parse_data(data_path):
     """
